@@ -1,6 +1,3 @@
-#ifndef ItemModel_h
-#define ItemModel_h
-
 //////////////////////////////////////////////////////////////////////////////
 // itemmodel.h
 // -------------------
@@ -10,6 +7,8 @@
 // SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
+#pragma once
+
 #include <QAbstractItemModel>
 
 namespace Breeze
@@ -93,5 +92,3 @@ private:
 };
 
 }
-
-#endif
