@@ -23,7 +23,7 @@ public:
      * Set the size of the box.
      * @param size The size of the box.
      **/
-    void setBoxSize(const QSize &size);
+    void setBoxSize(const QSizeF &size);
 
     /**
      * Set the radius of box' corners.
@@ -37,7 +37,7 @@ public:
      * @param radius The blur radius.
      * @param color The color of the shadow.
      **/
-    void addShadow(const QPoint &offset, int radius, const QColor &color);
+    void addShadow(const QPointF &offset, double radius, const QColor &color);
 
     /**
      * Render the shadow.
@@ -64,15 +64,15 @@ public:
      * @param radius The blur radius.
      * @param offset The offset of the shadow.
      **/
-    static QSize calculateMinimumShadowTextureSize(const QSize &boxSize, int radius, const QPoint &offset);
+    static QSizeF calculateMinimumShadowTextureSize(const QSizeF &boxSize, double radius, const QPointF &offset);
 
 private:
-    QSize m_boxSize;
+    QSizeF m_boxSize;
     qreal m_borderRadius = 0.0;
 
     struct Shadow {
-        QPoint offset;
-        int radius;
+        QPointF offset;
+        double radius;
         QColor color;
     };
 
